@@ -5,7 +5,7 @@ use utf8;
 use FindBin qw($RealBin);
 use lib "$RealBin/../lib";
 use lib "$RealBin/lib";
-use Bifcode qw( encode_bifcode decode_bifcode force_bifcode );
+use Bifcode::V2 qw( encode_bifcode decode_bifcode force_bifcode );
 use boolean;
 use Data::Dumper;
 use Path::Tiny;
